aboutsummaryrefslogtreecommitdiffstats
path: root/include/slibc-human.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/slibc-human.h')
-rw-r--r--include/slibc-human.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/slibc-human.h b/include/slibc-human.h
index ab89036..dbb0a98 100644
--- a/include/slibc-human.h
+++ b/include/slibc-human.h
@@ -42,19 +42,19 @@ enum humanmode_mode
* Return in the format where 0750
* resolves to 'rwxr-x---'.
*
* If used in combination with `MACHINEMODE_MASK`,
* 0750 resolves to 'u=rwx,g=r-x,o=---'.
*/
- MACHINEMODE_STAT = 1,
+ HUMANMODE_STAT = 1,
/**
* Return in the format where 0750
* resolves to 'u=rwx,g=rx,o='.
*
* If used in combination with `MACHINEMODE_STAT`,
* 0750 resolves to 'u=rwx,g=r-x,o=---'.
*/
- MACHINEMODE_MASK = 2,
+ HUMANMODE_MASK = 2,
};
@@ -42,19 +42,19 @@ enum humanmode_mode
* resolves to 'rwxr-x---'.
*
- * If used in combination with `MACHINEMODE_MASK`,
+ * If used in combination with `HUMANMODE_MASK`,
* 0750 resolves to 'u=rwx,g=r-x,o=---'.
*/
@@ -42,19 +42,19 @@ enum humanmode_mode
* resolves to 'u=rwx,g=rx,o='.
*
- * If used in combination with `MACHINEMODE_STAT`,
+ * If used in combination with `HUMANMODE_STAT`,
* 0750 resolves to 'u=rwx,g=r-x,o=---'.
*/